Struct Tree

pub struct Tree {
    pub tag: Tag,
    pub id: Option<Id>,
    pub state: State,
    pub children: Vec<Tree>,
}
A persistent state widget tree.

A Tree is normally associated with a specific widget in the widget tree.

Fields

tag: Tag

The tag of the Tree.

id: Option<Id>

the Id of the Tree

state: State

The State of the Tree.

children: Vec<Tree>

The children of the root widget of the Tree.

Implementations



impl Tree

pub fn empty() -> Tree

Creates an empty, stateless Tree with no children.

pub fn new<'a, Message, Theme, Renderer>( widget: impl Borrow<dyn Widget<Message, Theme, Renderer> + 'a>, ) -> Tree
where Renderer: Renderer,

Creates a new Tree for the provided Widget.

pub fn take_all_named( &mut self, ) -> HashMap<Cow<'static, str>, (State, Vec<(usize, Tree)>)>

Takes all named widgets from the tree.

pub fn find<'a>(&'a self, id: &Id) -> Option<&'a Tree>

Finds a widget state in the tree by its id.

pub fn diff<'a, Message, Theme, Renderer>( &mut self, new: impl BorrowMut<dyn Widget<Message, Theme, Renderer> + 'a>, )
where Renderer: Renderer,

Reconciliates the current tree with the provided Widget.

If the tag of the Widget matches the tag of the Tree, then the Widget proceeds with the reconciliation (i.e. Widget::diff is called).

Otherwise, the whole Tree is recreated.

pub fn diff_children<'a, Message, Theme, Renderer>( &mut self, new_children: &mut [impl BorrowMut<dyn Widget<Message, Theme, Renderer> + 'a>], )
where Renderer: Renderer,

Reconciles the children of the tree with the provided list of widgets.

pub fn diff_children_custom<T>( &mut self, new_children: &mut [T], new_ids: Vec<Option<Id>>, diff: impl Fn(&mut Tree, &mut T), new_state: impl Fn(&T) -> Tree, )

Reconciles the children of the tree with the provided list of widgets using custom logic both for diffing and creating new widget state.